---
title: Changing Top-Level Aircraft Requirements
summary: Instructions on where to change TLAR in the ACXML
authors:
    - Jens Vilöhr
date: 2024-12-04
---
When running the UNICADO workflow, the aircraft is sized based on requirements and specifications defined in the aircraft exchange file. This file holds initial parameters in an XML format, which ensure the final aircraft meets the design objectives and that can be modified to accommodate alternative goals or mission profiles.

## Overview of the Aircraft Exchange File
In its hierarchy, the most important parameters for the definition of the aircraft can be found in the sections 
`requirements_and_specifications/design_specifications`, where requirements regarding the configuration, transport task, propulsion and technologies are defined, and in `requirements_and_specifications/requirements`, where top-level aircraft requirements (TLARs) are defined. 
```
<aircraft_exchange_file>
└── <requirements_and_specifications>
    ├── ...
    ├── <design_specifications>
    │   └── Definition of configuration, transport task, propulsion, technologies
    ├── <requirements>
    │   └── Definition of TLARs
    └── ...
```
When modifying parameters, it is important to consider the intended design objective, as a change in the parameters will lead to a differently sized aircraft. Also, the given lower and upper boundary of the value should not be exceeded, which can be found in the corresponding XML tag. All numerical parameters have the following structure:
```
<parameter>
├── <value> The parameter will be set to this value
├── <unit> The unit of the parameter, can not be changed
├── <lower_boundary> Lower boundary, can not be changed
└── <upper_boundary> Upper boundary, can not be changed
```
When changing parameters, it is recommended to change only one parameter in the beginning to study how a change will affect the sizing of the aircraft. 

## Most important parameters
The following tables showcase the most important parameters that affect the sizing of the aircraft, as well as their location within the aircraft exchange file structure. For additional details about other parameters, refer to the descriptions provided within their corresponding XML tags.  

Definition of design mission related parameters:

|Parameter|Description|Path in Aircraft Exchange File|
|---|---|---|
|Design range|Operational range the aircraft will be designed to achieve.|`requirements_and_specifications/requirements/top_level_aircraft_requirements/design_mission/range`|
|Initial cruise mach number|Mach number at the beginning of the aircrafts cruise phase after climbing to its initial cruising altitude.|`requirements_and_specifications/requirements/top_level_aircraft_requirements/design_mission/initial_cruise_mach_number`|
|Initial cruise altitude|Altitude at the beginning of the aircrafts cruise phase.|`requirements_and_specifications/requirements/top_level_aircraft_requirements/design_mission/initial_cruise_altitude`|

Definition of transport task related parameters:

|Parameter|Description|Path in Aircraft Exchange File|
|---|---|---|
|Passenger number|Total number of passengers to accomodate. Make sure, that the maximum structural payload mass is changed accordingly.|`requirements_and_specifications/design_specification/transport_task/passenger_definition/total_number_passengers`|
|Additional Cargo Mass|Mass of cargo which does not belong to passengers. Make sure, that the maximum structural payload mass is changed accordingly.|`requirements_and_specifications/design_specification/transport_task/cargo_definition/additional_cargo_mass`|
|Maximum structural payload mass|Maximum structual payload mass which can be carried by the aircraft. Must at least include passenger and cargo mass.|`requirements_and_specifications/requirements/top_level_aircraft_requirements/maximum_structrual_payload_mass`|

Definition of the aircraft configuration:  

|Parameter|Description|Path in Aircraft Exchange File|
|---|---|---|
|Configuration Type|Currently, only a tube-and-wing configuration is supported. In future releases, a blended-wing-body configuration can be set here.|`requirements_and_specifications/design_specification/configuration/configuration_type`|
|Fuselage type|Change fuselage type between single-aisle and wide-body. If changed to wide-body, the seat-abreast in the fuselage_design_conf.xml must be adjusted to take two aisles into account as well.|`requirements_and_specifications/design_specification/configuration/fuselage_definition/fuselage_type`|
|Wing mounting|Vertical position of the wing. Can be low / mid / high.|`requirements_and_specifications/design_specification/configuration/wing_definition/mounting`|

Definition of constraints:

|Parameter|Description|Path in Aircraft Exchange File|
|---|---|---|
|Take-Off Distance|Design takeoff distance at Sea Level with maximum takeoff mass (MTOM)|`requirements_and_specifications/requirements/top_level_aircraft_requirements/takeoff_distance`|
|Landing Distance|Required runway length for landing at Sea Level with maximum landing mass (MLM)|`requirements_and_specifications/requirements/top_level_aircraft_requirements/landing_field_length`|


Note that the parameters displayed here are relevant to the sizing of the entire aircraft. For module-specific adjustments, the relevant parameters can be found in the configuration file of the corresponding module. For instance, to modify the wing sweep angle, the parameter can be located in the wing_design configuration file under `program_settings/tube_and_wing/cantilever/calculation_methods/sweep`. For further details, consult the documentation of the corresponding module.

